@@ -13,6 +13,7 @@
 import abc
 import json
 import typing as ty
+import warnings
 
 import typing_extensions as ty_ext
 
@@ -93,8 +94,8 @@ class BaseAuth(base.BaseIdentityPlugin, metaclass=abc.ABCMeta):
 
 
 class _AuthIdentity(ty.TypedDict):
-    identity: ty.Dict[str, ty.Any]
-    scope: ty_ext.NotRequired[ty.Union[ty.Dict[str, ty.Any], str]]
+    identity: dict[str, ty.Any]
+    scope: ty_ext.NotRequired[ty.Union[dict[str, ty.Any], str]]
 
 
 class _AuthBody(ty.TypedDict):
@@ -125,7 +126,7 @@ class Auth(BaseAuth):
     def __init__(
         self,
         auth_url: str,
-        auth_methods: ty.List['AuthMethod'],
+        auth_methods: list['AuthMethod'],
         *,
         unscoped: bool = False,
         trust_id: ty.Optional[str] = None,
@@ -159,14 +160,12 @@ class Auth(BaseAuth):
         """Add an additional initialized AuthMethod instance."""
         self.auth_methods.append(method)
 
-    def get_auth_ref(
-        self, session: ks_session.Session, **kwargs: ty.Any
-    ) -> access.AccessInfoV3:
+    def get_auth_ref(self, session: ks_session.Session) -> access.AccessInfoV3:
         headers = {'Accept': 'application/json'}
         body: _AuthBody = {'auth': {'identity': {}}}
         ident = body['auth']['identity']
         # this is passed around for its side-effects
-        rkwargs: ty.Dict[str, ty.Any] = {}
+        rkwargs: dict[str, ty.Any] = {}
 
         for method in self.auth_methods:
             name, auth_data = method.get_auth_data(
@@ -260,7 +259,7 @@ class Auth(BaseAuth):
             auth_token=resp.headers['X-Subject-Token'], body=resp_data
         )
 
-    def get_cache_id_elements(self) -> ty.Dict[str, ty.Optional[str]]:
+    def get_cache_id_elements(self) -> dict[str, ty.Optional[str]]:
         if not self.auth_methods:
             return {}
 
@@ -287,44 +286,50 @@ class Auth(BaseAuth):
 class AuthMethod(metaclass=abc.ABCMeta):
     """One part of a V3 Authentication strategy.
 
-    V3 Tokens allow multiple methods to be presented when authentication
-    against the server. Each one of these methods is implemented by an
-    AuthMethod.
+    The v3 '/tokens' API allow multiple methods to be presented when
+    authentication against the server. Each one of these methods is implemented
+    by an AuthMethod.
 
-    Note: When implementing an AuthMethod use the method_parameters
-    and do not use positional arguments. Otherwise they can't be picked up by
-    the factory method and don't work as well with AuthConstructors.
+    Note: When implementing an AuthMethod use keyword arguments to ensure they
+    are supported by the MultiFactor auth plugin.
     """
 
-    _method_parameters: ty.List[str] = []
+    #: Deprecated parameter for defining the parameters supported by the
+    #: plugin. These should now be defined by typed class attributes.
+    _method_parameters: ty.Optional[list[str]] = None
 
+    # TODO(stephenfin): Remove support for arbitrary arguments in 2025.2 or
+    # later
     def __init__(self, **kwargs: object):
-        for param in self._method_parameters:
-            setattr(self, param, kwargs.pop(param, None))
+        if self._method_parameters is not None:
+            warnings.warn(
+                "Defining method parameter via '_method_parameters' is "
+                "deprecated and will be removed in a future release. Migrate "
+                "to typed class attributes and define an '__init__' method.",
+                category=DeprecationWarning,
+            )
+
+            for param in self._method_parameters:
+                setattr(self, param, kwargs.pop(param, None))
 
         if kwargs:
             msg = "Unexpected Attributes: {}".format(", ".join(kwargs.keys()))
             raise AttributeError(msg)
 
     @classmethod
-    def _extract_kwargs(
-        cls, kwargs: ty.Dict[str, object]
-    ) -> ty.Dict[str, object]:
+    def _extract_kwargs(cls, kwargs: dict[str, object]) -> dict[str, object]:
         """Remove parameters related to this method from other kwargs."""
-        return {p: kwargs.pop(p, None) for p in cls._method_parameters}
+        _method_parameters = cls._method_parameters or []
+        return {p: kwargs.pop(p, None) for p in _method_parameters}
 
-    # TODO(stephenfin): Deprecate and remove unused kwargs
     @abc.abstractmethod
     def get_auth_data(
         self,
         session: ks_session.Session,
         auth: Auth,
-        headers: ty.Dict[str, str],
-        request_kwargs: ty.Dict[str, object],
-        **kwargs: ty.Any,
-    ) -> ty.Union[
-        ty.Tuple[None, None], ty.Tuple[str, ty.Mapping[str, object]]
-    ]:
+        headers: dict[str, str],
+        request_kwargs: dict[str, object],
+    ) -> ty.Union[tuple[None, None], tuple[str, ty.Mapping[str, object]]]:
         """Return the authentication section of an auth plugin.
 
         :param session: The communication session.
@@ -338,7 +343,7 @@ class AuthMethod(metaclass=abc.ABCMeta):
         """
         raise NotImplementedError()
 
-    def get_cache_id_elements(self) -> ty.Dict[str, ty.Optional[str]]:
+    def get_cache_id_elements(self) -> dict[str, ty.Optional[str]]:
         """Get the elements for this auth method that make it unique.
 
         These elements will be used as part of the
@@ -355,6 +360,11 @@ class AuthMethod(metaclass=abc.ABCMeta):
         raise NotImplementedError()
 
 
+@ty.runtime_checkable
+class SupportsMultiFactor(ty.Protocol):
+    _auth_method_class: ty.ClassVar[ty.Type[AuthMethod]]
+
+
 class AuthConstructor(Auth, metaclass=abc.ABCMeta):
     """Abstract base class for creating an Auth Plugin.
 
@@ -366,7 +376,7 @@ class AuthConstructor(Auth, metaclass=abc.ABCMeta):
     creates the auth plugin with only that authentication method.
     """
 
-    _auth_method_class: ty.Type[AuthMethod]
+    _auth_method_class: ty.ClassVar[ty.Type[AuthMethod]]
 
     def __init__(
         self,
@@ -385,6 +395,14 @@ class AuthConstructor(Auth, metaclass=abc.ABCMeta):
         include_catalog: bool = True,
         **kwargs: ty.Any,
     ):
+        warnings.warn(
+            f"'{AuthConstructor.__qualname__}' is deprecated and will be "
+            f"removed in a future release. Subclass '{Auth.__qualname__}' "
+            f"instead and define typed class attributes and an '__init__' "
+            f"method.",
+            category=DeprecationWarning,
+        )
+
         method_kwargs = self._auth_method_class._extract_kwargs(kwargs)
         # we should have consumed all "unknown" arguments by now
         assert kwargs == {}  # nosec B101
